#
# spec file for package thrift
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



%bcond_without perl
%bcond_without c
%bcond_without python
%bcond_with java
%bcond_with ruby
%bcond_without qt

Name:           thrift
Version:        0.9.2
Release:        2.4
%define libversion 0_9_2
%define libname    %{version}
Url:            https://thrift.apache.org
Source0:        https://www.apache.org/dist/thrift/%{version}/%{name}-%{version}.tar.gz
Source1:        https://www.apache.org/dist/thrift/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Summary:        Framework for scalable cross-language services development
License:        Apache-2.0
Group:          Development/Libraries/C and C++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  boost-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++

%if %{with qt}
BuildRequires:  qt-devel
%endif

%if %{with python}
BuildRequires:  python-devel
%endif

%if %{with c}
BuildRequires:  glib2-devel
%endif

%if %{with java}
BuildRequires:  java-devel
BuildRequires:	ant
%endif

%if %{with ruby}
BuildRequires:  ruby-devel
BuildRequires:	rubygem(bundler)
%endif

%if %{with perl}
BuildRequires:  perl
BuildRequires:  perl(Bit::Vector)
BuildRequires:  perl(Class::Accessor)
%endif

BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libevent-devel
BuildRequires:  openssl-devel
BuildRequires:  automake
BuildRequires:  pkg-config

%description
Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.

%package -n libthrift-%{libversion}
Summary:        Thrift shared library
Group:          System/Libraries

%description -n libthrift-%{libversion}
Thrift shared library

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.

%post -n libthrift-%{libversion} -p /sbin/ldconfig
%postun -n libthrift-%{libversion} -p /sbin/ldconfig

%package -n libthrift-devel
Summary:        Thrift C++ library development files
Group:          Development/Libraries
Requires:       libthrift-%{libversion} = %{version}

%description -n libthrift-devel
Thrift C++ library development files

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.

%if %{with perl}
%package -n perl-thrift
Summary:        Thrift perl library
Group:          Development/Libraries/Perl
%{perl_requires}

%description -n perl-thrift
Thrift perl library

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.
%endif

%if %{with python}
%package -n python-thrift
Summary:        Thrift python library
Group:          Development/Libraries/Python

%description -n python-thrift
Thrift python library

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.
%endif

%prep

%setup

%build
export CXXFLAGS="%{optflags} -fPIC"

# tests require static boost library
%configure \
	--disable-tests \
	--enable-static=no

%install
pushd compiler/cpp
%make_install
popd
pushd lib/cpp
%make_install
popd

%if %{with python}
pushd lib/py
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}%{python_sitearch}
popd
%endif

%if %{with perl}
pushd lib/perl
perl Makefile.PL
%perl_make_install
%perl_process_packlist
popd
%endif

rm %{buildroot}%{_libdir}/*.la

%files
%defattr(-,root,root)
%doc CHANGES LICENSE NOTICE
%{_bindir}/thrift

%files -n libthrift-%{libversion}
%defattr(-,root,root)
%{_libdir}/libthrift-*.so
%{_libdir}/libthriftnb-*.so
%{_libdir}/libthriftqt-*.so
%{_libdir}/libthriftz-*.so

%files -n libthrift-devel
%defattr(-,root,root)
%{_includedir}/thrift
%{_libdir}/libthrift.so
%{_libdir}/libthriftnb.so
%{_libdir}/libthriftqt.so
%{_libdir}/libthriftz.so
%{_libdir}/pkgconfig/*.pc

%if %{with perl}
%files -n perl-thrift
%defattr(-,root,root)
%{perl_vendorlib}/Thrift.pm
%{perl_vendorlib}/Thrift
%endif

%if %{with python}
%files -n python-thrift
%defattr(-,root,root)
%{py_sitedir}/*
%{python_sitearch}/*
%endif

%changelog
* Thu Mar  5 2015 mpluskal@suse.com
- Simplify buildconditions
* Mon Mar  2 2015 mpluskal@suse.com
- Disable building of static library
- Do not manually set LDFLAGS
* Mon Mar  2 2015 mpluskal@suse.com
- Remove obsolete patches
  * 0001-Add-missing-limits-header.patch
  * 0002-TNonblockingServer-TLibEventTransport.patch
  * 0003-TDenseProtocol.patch
- Update library name to match shlib naming policy
- Update to 0.9.2
  * numerous changes, see provide CHANGES for details
* Sat Feb 22 2014 opensuse@dstoecker.de
- enable perl and python packages
- remove extension patches
* Thu Feb 20 2014 opensuse@dstoecker.de
- update to 0.9.1
* Wed Sep 25 2013 d.desai@rtsgroup.net
- number of bytes written to transport and number of bytes
  returned from write() method was not same. Fixed this
  problem in TDenseProtocol.
* Thu Aug 15 2013 o.herrmann217@googlemail.com
- Extended 0002-TNonblockingServer-TLibEventTransport.patch to
  properly close TConnection when a client disconnects while
  still receiving updates from libevent.
* Wed Aug  7 2013 d.desai@rtsgroup.net
- Fixed multiple crashes in TNonblockingServer to work with lib_event.
* Fri Jun 21 2013 o.herrmann217@googlemail.com
- Changed 0002-TNonblockingServer-TLibEventTransport.patch to
  install new header file with automake.
* Thu Jun 20 2013 o.herrmann217@googlemail.com
- Replaced std::tr1::bind with boost::bind in TNonblockingServer
  to fix compilation error on RHEL 5.
* Thu Jun 20 2013 o.herrmann217@googlemail.com
- Removed BuildRequires for boost-static
* Thu Jun 20 2013 o.herrmann217@googlemail.com
- Created new patch for integrating external libevent clients in
  TNonblockingServer.
- Removed 0003-TNonblokingServer-release-handler-on-close.patch.
  It is now part of 0002-TNonblockingServer-TLibEventTransport.patch
* Tue May 14 2013 d.desai@rtsgroup.net
- Reverted changes for dependency of openssl for sles_11.
* Tue May 14 2013 d.desai@rtsgroup.net
- Added dependency of openssl for sles_11.
* Mon May 13 2013 d.desai@rtsgroup.net
- Created patch 0003 to release handler on close in
  TNonblockingServer
* Thu May  9 2013 o.herrmann217@googlemail.com
- Fixed reset of smart pointer in patch 0002
* Thu May  9 2013 o.herrmann217@googlemail.com
- Created patch 0002 to access event_base from libevent in
  TNonblockingServer
* Wed Jan 23 2013 d.desai@rtsgroup.net
- Removed boost version
* Wed Jan 23 2013 o.herrmann217@googlemail.com
- Build with --hash-style=sysv
* Sun Dec  2 2012 o.herrmann217@googlemail.com
- Striped one directory in patch 0001
* Sun Dec  2 2012 o.herrmann217@googlemail.com
- Patch for missing limit headers
* Sun Dec  2 2012 o.herrmann217@googlemail.com
- Call make with -j1 to fix compile problem temporally
* Tue Nov 27 2012 jblunck@opensuse.org
- Update to 0.9.0
* Fri Jul 30 2010 dmacvicar@novell.com
- initial package for 0.2.0
